@@ -671,6 +671,8 @@ class WebDriver(object):
 
         :Usage:
             Use the corresponding find_element_by_* instead of this.
+
+        :rtype: WebElement
         """
         if not By.is_valid(by) or not isinstance(value, str):
             raise InvalidSelectorException("Invalid locator values passed in")
@@ -684,6 +686,8 @@ class WebDriver(object):
 
         :Usage:
             Use the corresponding find_elements_by_* instead of this.
+
+        :rtype: list of WebElement
         """
         if not By.is_valid(by) or not isinstance(value, str):
             raise InvalidSelectorException("Invalid locator values passed in")
